﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.ComponentModel;
using System.Windows.Media.Imaging;

namespace ImageBindingDemo.ViewModels
{
public class ImageViewModel : INotifyPropertyChanged
{
    bool _isLoading;
    BitmapImage _img;
    int _progress;

    public ImageViewModel(string imageUrl) : this(imageUrl, null)
    {
    }
    public ImageViewModel(string imageUrl, BitmapImage fallbackImage)
    {
        if (string.IsNullOrEmpty(imageUrl))
        {
            _img = fallbackImage;
            return;
        }

        IsLoading = true;
        _img = new BitmapImage();
        _img.ImageOpened += (s, e) => { IsLoading = false; };
        _img.DownloadProgress += (s, e) => { DownloadProgress = e.Progress; };
        _img.ImageFailed += (s, e) =>
        {
            IsLoading = false;
            _img = FallbackImage;
            OnPropertyChanged("Image");
        };
        _img.UriSource = new Uri(imageUrl, UriKind.RelativeOrAbsolute);

        FallbackImage = fallbackImage;
    }

    public bool IsLoading
    {
        get { return _isLoading; }
        private set
        {
            if (value == _isLoading)
                return;

            _isLoading = value;
            OnPropertyChanged("IsLoading");
        }
    }
    public int DownloadProgress
    {
        get { return _progress; }
        private set
        {
            if (value == _progress)
                return;

            _progress = value;
            OnPropertyChanged("DownloadProgress");
        }
    }
    public BitmapImage Image
    {
        get { return _img; }
    }
    public BitmapImage FallbackImage
    {
        get;
        private set;
    }

    protected virtual void OnPropertyChanged(string propertyname)
    {
        if (PropertyChanged != null)
            PropertyChanged(this, new PropertyChangedEventArgs(propertyname));
    }
    public event PropertyChangedEventHandler PropertyChanged;
}
}
